PythonVersionFileSource

Struct PythonVersionFileSource 

pub struct PythonVersionFileSource { /* private fields */ }
Information regarding the file and TextRange of the configuration from which we inferred the Python version.

Implementations

Source

impl PythonVersionFileSource

pub fn new(path: Arc<SystemPathBuf>, range: Option<TextRange>) -> Self

pub fn span(&self, db: &dyn Db) -> Option<Span>

Attempt to resolve a Span that corresponds to the location of the configuration setting that specified the Python version.

Useful for subdiagnostics when informing the user what the inferred Python version of their project is.