pub struct PythonVersionWithSource {
pub version: PythonVersion,
pub source: PythonVersionSource,
}Expand description
A Python version with its source.
Fields
version: PythonVersionsource: PythonVersionSourceTrait Implementations
Sourceimpl Clone for PythonVersionWithSource
impl Clone for PythonVersionWithSource
Sourcefn clone(&self) -> PythonVersionWithSource
fn clone(&self) -> PythonVersionWithSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PythonVersionWithSource
impl Debug for PythonVersionWithSource
Sourceimpl Default for PythonVersionWithSource
impl Default for PythonVersionWithSource
impl Eq for PythonVersionWithSource
Sourceimpl GetSize for PythonVersionWithSource
impl GetSize for PythonVersionWithSource
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER: GetSizeTracker>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)
fn get_heap_size_with_tracker<TRACKER: GetSizeTracker>( &self, tracker: TRACKER, ) -> (usize, TRACKER)
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl Hash for PythonVersionWithSource
impl Hash for PythonVersionWithSource
Sourceimpl PartialEq for PythonVersionWithSource
impl PartialEq for PythonVersionWithSource
impl StructuralPartialEq for PythonVersionWithSource