pub struct SystemEnvironment { /* private fields */ }Expand description
A Python environment that is not a virtual environment.
This environment may or may not be one that is managed by the operating system itself, e.g., this captures both Homebrew-installed Python versions and the bundled macOS Python installation.