pub enum PythonVersionSource {
ConfigFile(PythonVersionFileSource),
ScriptMetadata(Span),
PyvenvCfgFile(PythonVersionFileSource),
InstallationDirectoryLayout {
site_packages_parent_dir: Box<str>,
source: Option<PythonVersionFileSource>,
},
Cli,
Editor,
UvWorkspace,
Default,
}Expand description
The source of the Python version.
Variants
ConfigFile(PythonVersionFileSource)
Value loaded from a project’s configuration file.
ScriptMetadata(Span)
Value configured in a standalone script’s inline metadata.
PyvenvCfgFile(PythonVersionFileSource)
Value loaded from the pyvenv.cfg file of the virtual environment.
The virtual environment might have been configured, activated or inferred.
InstallationDirectoryLayout
Value inferred from the layout of the Python installation.
This only ever applies on Unix. On Unix, the site-packages directory
will always be at sys.prefix/lib/pythonX.Y/site-packages,
so we can infer the Python version from the parent directory of site-packages.
Cli
The value comes from a CLI argument, while it’s left open if specified using a short argument,
long argument (--extra-paths) or --config key=value.
Editor
The value comes from the user’s editor, while it’s left open if specified as a setting or if the value was auto-discovered by the editor (e.g., the Python environment)
UvWorkspace
The value was provided by uv workspace metadata.
Default
We fell back to a default value because the value was not specified via the CLI or a config file.